@@ -178,16 +178,16 @@ class ArgParse:
 
         # Copy arguments over to an dict with server
         arguments = {k: v for k, v in arguments.items() if v is not None}
-        cfgfile = arguments.pop("cfgfile", "/dev/null")
+        cfgfile = arguments.pop("cfgfile", None)
         arguments = {"server": arguments}
 
         # Search for the configuration file
-        if not cfgfile and cfgfilepaths:
+        if cfgfile is None and cfgfilepaths:
             # Search for cfgfile
             cfgfilepaths = [e.format(cfgfilename=cfgfilename) for e in cfgfilepaths]
             cfgfile = which(cfgfile, expandpath(cfgfilepaths))
 
-        filedata = _read(cfgfile) or {}
+        filedata = _read(cfgfile or "/dev/null") or {}
 
         # Merge in the reverse order of priority
         cfg = defaults
